@@ -1,11 +1,17 @@
-#ifndef __GST_DEBUGGER_GST_UTILS_H__
-#define __GST_DEBUGGER_GST_UTILS_H__
+#ifndef SRC_COMMON_GST_UTILS_H_
+#define SRC_COMMON_GST_UTILS_H_
 
 #include <gst/gst.h>
 
 G_BEGIN_DECLS
 
-GstObject* gst_utils_get_root (GstObject * start);
+typedef struct {
+  gchar *type_name;
+} GstUnknownType;
+
+GType gst_unknown_type_get_type(void);
+
+GstUnknownType *gst_unknown_type_new (const gchar *type_name);
 
 GstElement* gst_utils_get_element_from_path (GstElement * root, const gchar * path);
 
@@ -21,4 +27,4 @@ GType gst_utils_get_virtual_flags_type (void);
 
 G_END_DECLS
 
-#endif /* __GST_DEBUGGER_GST_UTILS_H__ */
+#endif /* SRC_COMMON_GST_UTILS_H_ */
