@@ -12,11 +12,12 @@
 
 class GValueBoolean : public GValueBase
 {
+	Gtk::Widget* create_widget() override;
+
+	void update_widget(Gtk::Widget* widget) override;
 public:
 	GValueBoolean(GValue* gobj);
 
-	Gtk::Widget *get_widget() const override;
-
 	std::string to_string() const override;
 
 	bool get_value() const;
