@@ -14,25 +14,27 @@
 
 #include <boost/optional/optional.hpp>
 
+#include <mutex>
 #include <vector>
 #include <utility>
 
 class GValueEnum : public GValueBase
 {
 	boost::optional<GstEnumType> type;
+	std::mutex emit_m;
+
+	Gtk::Widget* create_widget() override;
+
+	void update_widget(Gtk::Widget* widget) override;
 
 public:
 	GValueEnum(GValue* gobj);
 
-	void set_type(GstEnumType type);
+	void set_type(GstEnumType type) { this->type = type; }
 
 	std::string to_string() const override;
 
 	gint get_value() const;
-
-	static std::vector<std::pair<int, std::string>> get_values(GType type);
-
-	Gtk::Widget* get_widget() const override;
 };
 
 #endif /* SRC_GST_DEBUGGER_GVALUE_CONVERTER_GVALUE_ENUM_H_ */
