@@ -19,10 +19,9 @@ MainWindow::MainWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   builder(builder),
   dispatcher(std::make_shared<Glib::Dispatcher>()),
   main_module(std::make_shared<MainModule>(builder)),
+  graph_module(std::make_shared<GraphModule>(builder)),
   properties_module(std::make_shared<GstPropertiesModule>(builder))
 {
-	graph_module = std::make_shared<GraphModule>(builder);
-
 	builder->get_widget("connectionPropertiesMenuItem", connection_properties);
 	connection_properties->signal_activate().connect(sigc::mem_fun(*this, &MainWindow::connectionPropertiesMenuItem_activate_cb));
 
@@ -32,6 +31,9 @@ MainWindow::MainWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
 	builder->get_widget("remoteFactoriesMenuitem", remote_factories);
 	remote_factories->signal_activate().connect([this] { factories_dialog->show(); });
 
+	builder->get_widget("remoteKlassesMenuitem", remote_klasses);
+	remote_klasses->signal_activate().connect([this] { klasses_dialog->show(); });
+
 	builder->get_widget("connectMenuItem", connect_menu_item);
 	connect_menu_item->signal_activate().connect(sigc::mem_fun(*this, &MainWindow::connectMenuItem_activate_cb));
 
@@ -45,6 +47,7 @@ MainWindow::MainWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
 
 	enums_dialog = load_dialog<EnumsDialog>("remoteDataDialog");
 	factories_dialog = load_dialog<FactoriesDialog>("remoteDataDialog");
+	klasses_dialog = load_dialog<KlassesDialog>("remoteDataDialog");
 	connection_properties_dialog = load_dialog<ConnectionPropertiesDialog>("connectionPropertiesDialog");
 
 	{
@@ -77,7 +80,6 @@ void MainWindow::set_controller(const std::shared_ptr<Controller> &controller)
 
 	main_module->set_controller(controller);
 	graph_module->set_controller(controller);
-	properties_module->set_controller(controller);
 
 	enums_dialog->set_controller(controller);
 	enums_dialog->set_transient_for(*this);
@@ -85,6 +87,11 @@ void MainWindow::set_controller(const std::shared_ptr<Controller> &controller)
 	factories_dialog->set_controller(controller);
 	factories_dialog->set_transient_for(*this);
 
+	klasses_dialog->set_controller(controller);
+	klasses_dialog->set_transient_for(*this);
+
+	properties_module->set_controller(controller);
+
 	connection_properties_dialog->set_transient_for(*this);
 }
 
@@ -117,4 +124,3 @@ void MainWindow::connection_status_changed(bool connected)
 		((Gtk::Label*)connect_menu_item->get_child())->set_text("Connect");
 	}
 }
-
