@@ -8,18 +8,17 @@
 #ifndef SRC_GST_DEBUGGER_MAIN_WINDOW_H_
 #define SRC_GST_DEBUGGER_MAIN_WINDOW_H_
 
-#include "controller/tcp_client.h"
 #include "dialogs/connection_properties_dialog.h"
 #include "dialogs/enums_dialog.h"
 #include "dialogs/factories_dialog.h"
-#include "modules/gst_properties_module.h"
+#include "dialogs/klasses_dialog.h"
 #include "modules/main_module.h"
+#include "modules/gst_properties_module.h"
 #include "pipeline-drawer/graph_module.h"
 
-#include <gtkmm.h>
-
 #include "controller/iview.h"
-#include "models/gst_enum_model.h"
+
+#include <gtkmm.h>
 
 #include <map>
 
@@ -33,23 +32,24 @@ class MainWindow : public IMainView
 	Gtk::MenuItem *connection_properties;
 	Gtk::MenuItem *remote_enum_types;
 	Gtk::MenuItem *remote_factories;
+	Gtk::MenuItem *remote_klasses;
 	Gtk::MenuItem *connect_menu_item;
 	Gtk::MenuItem *about_menu_item;
 	Gtk::MenuItem *quit_menu_item;
 
+	Gtk::AboutDialog *about_dialog;
+	Gtk::Statusbar *main_statusbar;
+
 	ConnectionPropertiesDialog *connection_properties_dialog;
 	EnumsDialog *enums_dialog;
 	FactoriesDialog *factories_dialog;
-	Gtk::AboutDialog *about_dialog;
-	Gtk::Statusbar *main_statusbar;
+	KlassesDialog *klasses_dialog;
 
 	std::shared_ptr<Glib::Dispatcher> dispatcher;
 	std::shared_ptr<MainModule> main_module;
 	std::shared_ptr<GraphModule> graph_module;
 	std::shared_ptr<GstPropertiesModule> properties_module;
 
-	GstreamerInfo info;
-
 public:
 	MainWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
 	virtual ~MainWindow() {}
