@@ -6,8 +6,6 @@
  */
 
 #include "gst_properties_module.h"
-#include "gvalue-converter/gvalue_enum.h"
-#include "common/deserializer.h"
 #include "controller/command_factory.h"
 #include "controller/controller.h"
 #include "controller/element_path_processor.h"
@@ -15,7 +13,7 @@
 
 #include <gst/gst.h>
 
-static void free_properties(Property *property) { delete property; }
+static void free_properties(GstDebugger::PropertyInfo *property) { delete property; }
 
 GstPropertiesModule::GstPropertiesModule(const Glib::RefPtr<Gtk::Builder>& builder)
 {
@@ -31,13 +29,13 @@ GstPropertiesModule::GstPropertiesModule(const Glib::RefPtr<Gtk::Builder>& build
 void GstPropertiesModule::set_controller(const std::shared_ptr<Controller> &controller)
 {
 	IBaseView::set_controller(controller);
-	controller->on_property_received.connect(sigc::mem_fun(*this, &GstPropertiesModule::new_property));
+	controller->on_property_value_received.connect(sigc::mem_fun(*this, &GstPropertiesModule::new_property));
 	controller->on_selected_object_changed.connect(sigc::mem_fun(*this, &GstPropertiesModule::selected_object_changed));
 }
 
-void GstPropertiesModule::new_property(const Property &property)
+void GstPropertiesModule::new_property(const GstDebugger::PropertyValue &property)
 {
-	gui_push("property", new Property (property));
+	gui_push("property", new GstDebugger::PropertyValue(property));
 	gui_emit("property");
 }
 
@@ -66,31 +64,31 @@ void GstPropertiesModule::showPropertiesButton_clicked_cb()
 
 void GstPropertiesModule::new_property_()
 {
-	auto property = gui_pop<Property*>("property");
+	auto property = gui_pop<GstDebugger::PropertyValue*>("property");
 
-	auto element = std::dynamic_pointer_cast<ElementModel>(ElementPathProcessor(property->element_path()).get_last_obj());
+	auto element = std::dynamic_pointer_cast<ElementModel>(ElementPathProcessor(property->object()).get_last_obj());
 	if (!element)
 	{
 		return;
 	}
 
-	std::shared_ptr<GValueBase> value_base = element->get_property(property->property_name());
-	std::shared_ptr<GValueEnum> value_enum = std::dynamic_pointer_cast<GValueEnum>(value_base);
+	std::shared_ptr<GValueBase> value_base = element->get_property(property->name());
+	/*std::shared_ptr<GValueEnum> value_enum = std::dynamic_pointer_cast<GValueEnum>(value_base);
 
-	auto& container = const_cast<RemoteDataContainer<GstEnumType>&>(controller->get_enum_container());
-	if (value_enum && container.has_item(property->type_name()))
+	if (value_enum && controller->get_enum_type(property->value().type_name()))
 	{
-		value_enum->set_type(container.get_item(property->type_name()));
+		value_enum->set_type(container.get_item(property->value().type_name()));
+	}*/
+
+	if (!update_property(value_base, property->name()))
+	{
+		append_property(value_base, property->name());
 	}
 
-	if (!update_property(value_base, property))
-	{
-		append_property(value_base, property);
-	}
 	delete property;
 }
 
-bool GstPropertiesModule::update_property(const std::shared_ptr<GValueBase>& value_base, Property *property)
+bool GstPropertiesModule::update_property(const std::shared_ptr<GValueBase>& value_base, const std::string prop_name)
 {
 	for (auto internal_box : properties_box->get_children())
 	{
@@ -100,59 +98,50 @@ bool GstPropertiesModule::update_property(const std::shared_ptr<GValueBase>& val
 			continue;
 		}
 
-		Gtk::Label *label = nullptr;
-		Gtk::Widget *widget = nullptr;
-
-		for (auto cd : hb->get_children())
-		{
-			if (label == nullptr && (label = dynamic_cast<Gtk::Label*>(cd)) != nullptr)
-			{
-				if (label->get_text() != property->property_name())
-				{
-					label = nullptr;
-					break;
-				}
-			}
-			else if (dynamic_cast<Gtk::Button*>(cd) == nullptr || dynamic_cast<Gtk::CheckButton*>(cd) != nullptr)
-			{
-				widget = cd;
-			}
-		}
-
-		if (label == nullptr || widget == nullptr)
-		{
+		if (reinterpret_cast<gchar*>(hb->get_data("property-name")) != prop_name)
 			continue;
-		}
 
-		hb->remove(*widget);
-		widget = value_base->get_widget();
-		widget->show();
-		hb->pack_start(*widget, true, 10);
-		hb->reorder_child(*widget, 1);
-		return true;
+		for (auto widget : hb->get_children())
+		{
+			if (widget->get_data("is-gvalue-widget") == GINT_TO_POINTER(1))
+			{
+				bool sensitive = widget->get_sensitive();
+				hb->remove(*widget);
+				widget = value_base->get_widget();
+				widget->set_sensitive(sensitive);
+				widget->show();
+				hb->pack_start(*widget, true, 10);
+				hb->reorder_child(*widget, 1);
+				return true;
+			}
+		}
 	}
 
 	return false;
 }
 
-void GstPropertiesModule::append_property(const std::shared_ptr<GValueBase>& value_base, Property *property)
+void GstPropertiesModule::append_property(const std::shared_ptr<GValueBase>& value_base, const std::string &prop_name)
 {
+	auto e = std::dynamic_pointer_cast<ElementModel>(controller->get_selected_object());
+	if (!e) return;
+	auto klass = controller->get_klass(e->get_type_name());
+	if (!klass) return;
+	auto prop = klass.get().get_property(prop_name);
+	if (!prop) return;
+
 	Gtk::Box *hbox = new Gtk::Box (Gtk::ORIENTATION_HORIZONTAL, 0);
-	hbox->show();
-	auto prop_name = property->property_name();
+	hbox->set_data("property-name", g_strdup (prop_name.c_str()), g_free);
 	Gtk::Label *lbl = Gtk::manage(new Gtk::Label(prop_name));
-	lbl->set_tooltip_text(property->description());
-	lbl->show();
+	lbl->set_tooltip_text(prop->get_blurb());
 	Gtk::Button *btn = Gtk::manage(new Gtk::Button("Refresh"));
 	btn->signal_clicked().connect([this, prop_name] {request_selected_element_property(prop_name);});
-	btn->show();
 	hbox->pack_start(*lbl, false, false);
 	auto value_widget = value_base->get_widget();
-	value_widget->show();
-	value_widget->set_sensitive(property->flags() & G_PARAM_WRITABLE);
+	value_base->set_sensitive(prop.get().get_flags() & G_PARAM_WRITABLE);
 	hbox->pack_start(*value_widget, true, true);
 	hbox->pack_start(*btn, false, false);
 	properties_box->pack_start(*hbox);
+	hbox->show_all();
 }
 
 void GstPropertiesModule::clear_widgets()
