@@ -25,13 +25,13 @@ private:
 
 	std::string previous_element_path;
 
-	void append_property(const std::shared_ptr<GValueBase>& value_base, Property *property);
-	bool update_property(const std::shared_ptr<GValueBase>& value_base, Property *property);
+	void append_property(const std::shared_ptr<GValueBase>& value_base, const std::string &prop_name);
+	bool update_property(const std::shared_ptr<GValueBase>& value_base, const std::string prop_name);
 	void request_selected_element_property(const std::string &property_name);
 
 	void show_pad_properties();
 
-	void new_property(const Property& property);
+	void new_property(const GstDebugger::PropertyValue& property);
 	void new_property_();
 
 	void selected_object_changed();
