@@ -11,51 +11,40 @@
 #include "base_main_module.h"
 #include "control_module.h"
 
-class GstreamerLog;
-
-class LogModelColumns : public Gtk::TreeModel::ColumnRecord
-{
-public:
-	LogModelColumns() {
-		add(header); add(log);
-	}
-
-	Gtk::TreeModelColumn<Glib::ustring> header;
-	Gtk::TreeModelColumn<GstreamerLog*> log;
-};
-
 class LogModule : public BaseMainModule
 {
-	void log_received_();
-
-	LogModelColumns columns;
-
-protected:
-	bool filter_function(const Gtk::TreeModel::const_iterator& it) override;
+	void data_received(const Gtk::TreeModel::Row& row, GstDebugger::GStreamerData *data) override;
+	void load_details(gpointer data) override;
 
 public:
 	LogModule();
 	virtual ~LogModule() {}
-
-	void configure_main_list_view(Gtk::TreeView *view) override;
-	void load_details(Gtk::TreeView *view, const Gtk::TreeModel::Path &path) override;
-
-	void set_controller(const std::shared_ptr<Controller> &controller) override;
 };
 
 class LogControlModule : public ControlModule
 {
-	Gtk::Box *main_box;
-	Gtk::CheckButton *set_watch_button;
 	Gtk::CheckButton *overwrite_threshold_check_button;
+	Gtk::ComboBoxText *log_levels_combobox;
+	Gtk::ComboBoxText *debug_categories_combobox;
 	Gtk::Button *set_threshold_button;
 	Gtk::Entry *threshold_entry;
 
+	void add_hook() override;
+	void remove_hook(const Gtk::TreeModel::Row& row) override;
+	void confirmation_received(GstDebugger::Command* cmd) override;
+
+	bool hook_is_the_same(const Gtk::TreeModel::Row& row, gconstpointer confirmation) override
+	{
+		auto log = reinterpret_cast<const GstDebugger::LogRequest*>(confirmation);
+		return row[hooks_model_columns.int1] == log->level() &&
+			row[hooks_model_columns.str2] == log->category();
+	}
+
 public:
 	LogControlModule();
 	virtual ~LogControlModule() {}
 
-	Gtk::Widget* get_widget() override;
+	void set_controller(const std::shared_ptr<Controller> &controller) override;
 };
 
 #endif /* SRC_GST_DEBUGGER_MODULES_LOG_MODULE_H_ */
